@@ -1,22 +1,8 @@
 /*
-    Copyright 2012-2013  Jan Grulich <jgrulich@redhat.com>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2012-2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "ipv4setting.h"
@@ -39,12 +25,14 @@ NetworkManager::Ipv4SettingPrivate::Ipv4SettingPrivate()
     , mayFail(true)
     , dadTimeout(-1)
     , dnsPriority(0)
-{ }
+{
+}
 
 NetworkManager::Ipv4Setting::Ipv4Setting()
     : Setting(Setting::Ipv4)
     , d_ptr(new Ipv4SettingPrivate())
-{ }
+{
+}
 
 NetworkManager::Ipv4Setting::Ipv4Setting(const Ptr &other)
     : Setting(other)
@@ -132,7 +120,7 @@ void NetworkManager::Ipv4Setting::setAddresses(const QList<IpAddress> &ipv4addre
     d->addresses = ipv4addresses;
 }
 
-QList< NetworkManager::IpAddress > NetworkManager::Ipv4Setting::addresses() const
+QList<NetworkManager::IpAddress> NetworkManager::Ipv4Setting::addresses() const
 {
     Q_D(const Ipv4Setting);
 
@@ -146,7 +134,7 @@ void NetworkManager::Ipv4Setting::setRoutes(const QList<IpRoute> &ipv4routes)
     d->routes = ipv4routes;
 }
 
-QList< NetworkManager::IpRoute > NetworkManager::Ipv4Setting::routes() const
+QList<NetworkManager::IpRoute> NetworkManager::Ipv4Setting::routes() const
 {
     Q_D(const Ipv4Setting);
 
@@ -388,12 +376,12 @@ void NetworkManager::Ipv4Setting::fromMap(const QVariantMap &setting)
         QList<uint> temp;
         if (setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_DNS)).canConvert<QDBusArgument>()) {
             QDBusArgument dnsArg = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_DNS)).value<QDBusArgument>();
-            temp = qdbus_cast<QList<uint> >(dnsArg);
+            temp = qdbus_cast<QList<uint>>(dnsArg);
         } else {
-            temp = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_DNS)).value<QList<uint> >();
+            temp = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_DNS)).value<QList<uint>>();
         }
 
-        Q_FOREACH (const uint utmp, temp) {
+        for (const uint utmp : std::as_const(temp)) {
             QHostAddress tmpHost(ntohl(utmp));
             dbusDns << tmpHost;
         }
@@ -407,15 +395,15 @@ void NetworkManager::Ipv4Setting::fromMap(const QVariantMap &setting)
 
     if (setting.contains(QLatin1String(NMQT_SETTING_IP4_CONFIG_ADDRESSES))) {
         QList<NetworkManager::IpAddress> addresses;
-        QList<QList<uint> > temp;
-        if (setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ADDRESSES)).canConvert< QDBusArgument>()) {
+        QList<QList<uint>> temp;
+        if (setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ADDRESSES)).canConvert<QDBusArgument>()) {
             QDBusArgument addressArg = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ADDRESSES)).value<QDBusArgument>();
-            temp = qdbus_cast<QList<QList<uint> > >(addressArg);
+            temp = qdbus_cast<QList<QList<uint>>>(addressArg);
         } else {
-            temp = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ADDRESSES)).value<QList<QList<uint> > >();
+            temp = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ADDRESSES)).value<QList<QList<uint>>>();
         }
 
-        Q_FOREACH (const QList<uint> &uintList, temp) {
+        for (const QList<uint> &uintList : std::as_const(temp)) {
             if (uintList.count() != 3) {
                 continue;
             }
@@ -436,15 +424,15 @@ void NetworkManager::Ipv4Setting::fromMap(const QVariantMap &setting)
 
     if (setting.contains(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTES))) {
         QList<NetworkManager::IpRoute> routes;
-        QList<QList<uint> > temp;
-        if (setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTES)).canConvert< QDBusArgument>()) {
+        QList<QList<uint>> temp;
+        if (setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTES)).canConvert<QDBusArgument>()) {
             QDBusArgument routeArg = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTES)).value<QDBusArgument>();
-            temp = qdbus_cast<QList<QList<uint> > >(routeArg);
+            temp = qdbus_cast<QList<QList<uint>>>(routeArg);
         } else {
-            temp = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTES)).value<QList<QList<uint> > >();
+            temp = setting.value(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTES)).value<QList<QList<uint>>>();
         }
 
-        Q_FOREACH (const QList<uint> &uintList, temp) {
+        for (const QList<uint> &uintList : std::as_const(temp)) {
             if (uintList.count() != 4) {
                 continue;
             }
@@ -544,7 +532,8 @@ QVariantMap NetworkManager::Ipv4Setting::toMap() const
 
     if (!dns().isEmpty()) {
         QList<uint> dbusDns;
-        Q_FOREACH (const QHostAddress & dns, dns()) {
+        const QList<QHostAddress> dnsList = dns();
+        for (const QHostAddress &dns : dnsList) {
             dbusDns << htonl(dns.toIPv4Address());
         }
 
@@ -556,12 +545,11 @@ QVariantMap NetworkManager::Ipv4Setting::toMap() const
     }
 
     if (!addresses().isEmpty()) {
-        QList<QList<uint> > dbusAddresses;
-        Q_FOREACH (const NetworkManager::IpAddress & addr, addresses()) {
+        QList<QList<uint>> dbusAddresses;
+        const auto addressesList = addresses();
+        for (const NetworkManager::IpAddress &addr : addressesList) {
             QList<uint> dbusAddress;
-            dbusAddress << htonl(addr.ip().toIPv4Address())
-                        << addr.prefixLength()
-                        << htonl(addr.gateway().toIPv4Address());
+            dbusAddress << htonl(addr.ip().toIPv4Address()) << addr.prefixLength() << htonl(addr.gateway().toIPv4Address());
             dbusAddresses << dbusAddress;
         }
 
@@ -569,20 +557,18 @@ QVariantMap NetworkManager::Ipv4Setting::toMap() const
     }
 
     if (!routes().isEmpty()) {
-        QList<QList<uint> > dbusRoutes;
-        Q_FOREACH (const NetworkManager::IpRoute & route, routes()) {
+        QList<QList<uint>> dbusRoutes;
+        const auto routesList = routes();
+        for (const NetworkManager::IpRoute &route : routesList) {
             QList<uint> dbusRoute;
-            dbusRoute << htonl(route.ip().toIPv4Address())
-                      << route.prefixLength()
-                      << htonl(route.nextHop().toIPv4Address())
-                      << route.metric();
+            dbusRoute << htonl(route.ip().toIPv4Address()) << route.prefixLength() << htonl(route.nextHop().toIPv4Address()) << route.metric();
             dbusRoutes << dbusRoute;
         }
 
         setting.insert(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTES), QVariant::fromValue(dbusRoutes));
     }
 
-    if(routeMetric() >= 0) {
+    if (routeMetric() >= 0) {
         setting.insert(QLatin1String(NMQT_SETTING_IP4_CONFIG_ROUTE_METRIC), routeMetric());
     }
 
@@ -615,7 +601,7 @@ QVariantMap NetworkManager::Ipv4Setting::toMap() const
     }
 
     if (dadTimeout() >= 0) {
-	setting.insert(QLatin1String(NMQT_SETTING_IP4_CONFIG_DAD_TIMEOUT), dadTimeout());
+        setting.insert(QLatin1String(NMQT_SETTING_IP4_CONFIG_DAD_TIMEOUT), dadTimeout());
     }
 
     if (!dhcpFqdn().isEmpty()) {
@@ -645,23 +631,26 @@ QVariantMap NetworkManager::Ipv4Setting::toMap() const
     return setting;
 }
 
-QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::Ipv4Setting &setting)
+QDebug NetworkManager::operator<<(QDebug dbg, const NetworkManager::Ipv4Setting &setting)
 {
     dbg.nospace() << "type: " << setting.typeAsString(setting.type()) << '\n';
     dbg.nospace() << "initialized: " << !setting.isNull() << '\n';
 
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_METHOD << ": " << setting.method() << '\n';
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_DNS << ":\n";
-    Q_FOREACH (const QHostAddress & address, setting.dns()) {
+    const QList<QHostAddress> dnsList = setting.dns();
+    for (const QHostAddress &address : dnsList) {
         dbg.nospace() << address.toString() << '\n';
     }
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_DNS_SEARCH << ": " << setting.dnsSearch() << '\n';
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_ADDRESSES << '\n';
-    Q_FOREACH (const NetworkManager::IpAddress & address, setting.addresses()) {
+    const auto addressesList = setting.addresses();
+    for (const NetworkManager::IpAddress &address : addressesList) {
         dbg.nospace() << address.ip() << ": " << address.gateway() << ": " << address.netmask() << '\n';
     }
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_ROUTES << '\n';
-    Q_FOREACH (const NetworkManager::IpRoute & route, setting.routes()) {
+    const auto routesList = setting.routes();
+    for (const NetworkManager::IpRoute &route : routesList) {
         dbg.nospace() << route.ip() << ": " << route.netmask() << ": " << route.nextHop() << ": " << route.metric() << '\n';
     }
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_ROUTE_METRIC << ":" << setting.routeMetric() << '\n';
@@ -678,18 +667,20 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::Ipv4Setting
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_DNS_PRIORITY << ": " << setting.dnsPriority() << '\n';
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_GATEWAY << ": " << setting.gateway() << '\n';
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_ADDRESS_DATA << ": " << '\n';
-    Q_FOREACH (const QVariantMap & addressData, setting.addressData()) {
+    const NMVariantMapList addDataList = setting.addressData();
+    for (const QVariantMap &addressData : addDataList) {
         QVariantMap::const_iterator i = addressData.constBegin();
         while (i != addressData.constEnd()) {
-	    dbg.nospace() << i.key() << ": " << i.value() << '\n';
-	}
+            dbg.nospace() << i.key() << ": " << i.value() << '\n';
+        }
     }
     dbg.nospace() << NMQT_SETTING_IP4_CONFIG_ROUTE_DATA << ": " << '\n';
-    Q_FOREACH (const QVariantMap & routeData, setting.routeData()) {
+    const NMVariantMapList routeDataList = setting.routeData();
+    for (const QVariantMap &routeData : routeDataList) {
         QVariantMap::const_iterator i = routeData.constBegin();
         while (i != routeData.constEnd()) {
             dbg.nospace() << i.key() << ": " << i.value() << '\n';
-	}
+        }
     }
 
     return dbg.maybeSpace();
