@@ -11,6 +11,8 @@
 
 #include "nmdebug.h"
 
+#include <QDBusMetaType>
+
 NetworkManager::WimaxDevicePrivate::WimaxDevicePrivate(const QString &path, WimaxDevice *q)
     : DevicePrivate(path, q)
 #ifdef NMQT_STATIC
@@ -32,19 +34,13 @@ NetworkManager::WimaxDevice::WimaxDevice(const QString &path, QObject *parent)
 {
     Q_D(WimaxDevice);
 
+    connect(&d->wimaxIface, &OrgFreedesktopNetworkManagerDeviceWiMaxInterface::NspAdded, d, &WimaxDevicePrivate::nspAdded);
+    connect(&d->wimaxIface, &OrgFreedesktopNetworkManagerDeviceWiMaxInterface::NspRemoved, d, &WimaxDevicePrivate::nspRemoved);
+
     QVariantMap initialProperties = NetworkManagerPrivate::retrieveInitialProperties(d->wimaxIface.staticInterfaceName(), path);
     if (!initialProperties.isEmpty()) {
         d->propertiesChanged(initialProperties);
     }
-
-    QDBusConnection::systemBus().connect(NetworkManagerPrivate::DBUS_SERVICE,
-                                         d->uni,
-                                         NetworkManagerPrivate::FDO_DBUS_PROPERTIES,
-                                         QLatin1String("PropertiesChanged"),
-                                         d,
-                                         SLOT(dbusPropertiesChanged(QString, QVariantMap, QStringList)));
-    connect(&d->wimaxIface, &OrgFreedesktopNetworkManagerDeviceWiMaxInterface::NspAdded, d, &WimaxDevicePrivate::nspAdded);
-    connect(&d->wimaxIface, &OrgFreedesktopNetworkManagerDeviceWiMaxInterface::NspRemoved, d, &WimaxDevicePrivate::nspRemoved);
 }
 
 NetworkManager::WimaxDevice::~WimaxDevice()
@@ -169,3 +165,6 @@ void NetworkManager::WimaxDevicePrivate::propertyChanged(const QString &property
         DevicePrivate::propertyChanged(property, value);
     }
 }
+
+#include "moc_wimaxdevice.cpp"
+#include "moc_wimaxdevice_p.cpp"
